==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebLinearProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebLinearProgressDescription } from "./WebLinearProgressDescription";
/**
 * @hidden
 */
var WebLinearProgressDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebLinearProgressDescriptionMetadata, _super);
    function WebLinearProgressDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebLinearProgressDescriptionMetadata.b = function (a) {
        if (WebLinearProgressDescriptionMetadata.a == null) {
            WebLinearProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebLinearProgressDescriptionMetadata.c(WebLinearProgressDescriptionMetadata.a);
        }
        if (a.k(WebLinearProgressDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebLinearProgressDescriptionMetadata.a);
    };
    WebLinearProgressDescriptionMetadata.c = function (a) {
        WebProgressBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:LinearProgress");
        a.item("__tagNameWC", "String:igc-linear-progress");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Striped", "Boolean");
        a.item("LabelAlign", "ExportedType:string:LinearProgressLabelAlign");
        a.item("LabelAlign@stringUnion", "WebComponents;React");
        a.item("LabelAlign@names", "Top;TopStart;TopEnd;Bottom;BottomStart;BottomEnd");
    };
    WebLinearProgressDescriptionMetadata.d = function (a) {
        WebLinearProgressDescriptionMetadata.b(a);
        a.ad("WebLinearProgress", function () { return new WebLinearProgressDescription(); });
        a.ac("WebLinearProgress", WebLinearProgressDescriptionMetadata.a);
    };
    WebLinearProgressDescriptionMetadata.$t = markType(WebLinearProgressDescriptionMetadata, 'WebLinearProgressDescriptionMetadata');
    WebLinearProgressDescriptionMetadata.a = null;
    return WebLinearProgressDescriptionMetadata;
}(Base));
export { WebLinearProgressDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebLinearProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebLinearProgressDescription } from "./WebLinearProgressDescription";
/**
 * @hidden
 */
var WebLinearProgressDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebLinearProgressDescriptionMetadata, _super);
    function WebLinearProgressDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebLinearProgressDescriptionMetadata.b = function (a) {
        if (WebLinearProgressDescriptionMetadata.a == null) {
            WebLinearProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebLinearProgressDescriptionMetadata.c(WebLinearProgressDescriptionMetadata.a);
        }
        if (a.k(WebLinearProgressDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebLinearProgressDescriptionMetadata.a);
    };
    WebLinearProgressDescriptionMetadata.c = function (a) {
        WebProgressBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:LinearProgress");
        a.item("__tagNameWC", "String:igc-linear-progress");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Striped", "Boolean");
        a.item("LabelAlign", "ExportedType:string:LinearProgressLabelAlign");
        a.item("LabelAlign@stringUnion", "WebComponents;React");
        a.item("LabelAlign@names", "Bottom;Top;TopStart;TopEnd;BottomStart;BottomEnd");
    };
    WebLinearProgressDescriptionMetadata.d = function (a) {
        WebLinearProgressDescriptionMetadata.b(a);
        a.ae("WebLinearProgress", function () { return new WebLinearProgressDescription(); });
        a.ad("WebLinearProgress", WebLinearProgressDescriptionMetadata.a);
    };
    WebLinearProgressDescriptionMetadata.$t = markType(WebLinearProgressDescriptionMetadata, 'WebLinearProgressDescriptionMetadata');
    WebLinearProgressDescriptionMetadata.a = null;
    return WebLinearProgressDescriptionMetadata;
}(Base));
export { WebLinearProgressDescriptionMetadata };
